@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,19 @@ class PluginsDialog : public QDialog, private Ui_PluginsDialog
   Q_OBJECT
 
  public:
-  PluginsDialog(StationsPluginManager *manager, QWidget *parent = 0);
+  PluginsDialog(StationsPluginManager *manager, bool localization,
+		QWidget *parent = 0);
   ~PluginsDialog();
 
   StationsPlugin *plugin();
 
+ public:
+  void setCurrentPlugin(StationsPlugin *plugin);
+
  private slots:
   void itemClicked(QTreeWidgetItem *item, int column);
   void itemDoubleClicked(QTreeWidgetItem *item, int column);
+  void itemSelectionChanged();
   void filter(const QString &str);
 
  private:
