@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,9 +49,7 @@ private slots:
 
   void requestError(QNetworkReply::NetworkError code);
   void requestFinished();
-#if !defined(Q_WS_S60) && !defined(Q_WS_SIMULATOR)
   void orientationChanged();
-#endif
 
 private:
   Station *station;
