@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010 Corentin Chary <corentin.chary@gmail.com>
+ * Copyright (C) 2010-2011 Corentin Chary <corentin.chary@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,15 @@
 
 #include "stationspluginfactorysimple.h"
 
-class StationsPluginFactoryUsa : public QObject, public StationsPluginFactorySimple
+class StationsPluginFactoryUsa : public StationsPluginFactorySimple
 {
   Q_OBJECT
   Q_INTERFACES(StationsPluginFactory)
  public:
   StationsPluginFactoryUsa();
+
+ protected:
+  StationsPluginSimple *pluginForType(const QString & type);
 };
 
 #endif /* STATIONS_USA_H */
